==> igniteui-webcomponents-core-3.2.2.tgz: package/esm5/lib/GeographicMapSeriesHostDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
/**
 * @hidden
 */
var GeographicMapSeriesHostDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GeographicMapSeriesHostDescriptionMetadata, _super);
    function GeographicMapSeriesHostDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GeographicMapSeriesHostDescriptionMetadata.b = function (a) {
        if (GeographicMapSeriesHostDescriptionMetadata.a == null) {
            GeographicMapSeriesHostDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GeographicMapSeriesHostDescriptionMetadata.c(GeographicMapSeriesHostDescriptionMetadata.a);
        }
        if (a.g(GeographicMapSeriesHostDescriptionMetadata.a)) {
            return;
        }
        a.s(GeographicMapSeriesHostDescriptionMetadata.a);
    };
    GeographicMapSeriesHostDescriptionMetadata.c = function (a) {
        SeriesDescriptionMetadata.c(a);
        a.item("VisibleFromScale", "Number:double");
        a.item("CoercionMethodsRef", "(w:CoercionMethods,wf:CoercionMethods)DataRef");
    };
    GeographicMapSeriesHostDescriptionMetadata.d = function (a) {
        GeographicMapSeriesHostDescriptionMetadata.b(a);
        a.t("GeographicMapSeriesHost", GeographicMapSeriesHostDescriptionMetadata.a);
    };
    GeographicMapSeriesHostDescriptionMetadata.$t = markType(GeographicMapSeriesHostDescriptionMetadata, 'GeographicMapSeriesHostDescriptionMetadata');
    GeographicMapSeriesHostDescriptionMetadata.a = null;
    return GeographicMapSeriesHostDescriptionMetadata;
}(Base));
export { GeographicMapSeriesHostDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/GeographicMapSeriesHostDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
/**
 * @hidden
 */
var GeographicMapSeriesHostDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GeographicMapSeriesHostDescriptionMetadata, _super);
    function GeographicMapSeriesHostDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GeographicMapSeriesHostDescriptionMetadata.b = function (a) {
        if (GeographicMapSeriesHostDescriptionMetadata.a == null) {
            GeographicMapSeriesHostDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GeographicMapSeriesHostDescriptionMetadata.c(GeographicMapSeriesHostDescriptionMetadata.a);
        }
        if (a.j(GeographicMapSeriesHostDescriptionMetadata.a)) {
            return;
        }
        a.y(GeographicMapSeriesHostDescriptionMetadata.a);
    };
    GeographicMapSeriesHostDescriptionMetadata.c = function (a) {
        SeriesDescriptionMetadata.c(a);
        a.item("VisibleFromScale", "Number:double");
        a.item("CoercionMethodsRef", "(w:CoercionMethods,wf:CoercionMethods)DataRef");
    };
    GeographicMapSeriesHostDescriptionMetadata.d = function (a) {
        GeographicMapSeriesHostDescriptionMetadata.b(a);
        a.z("GeographicMapSeriesHost", GeographicMapSeriesHostDescriptionMetadata.a);
    };
    GeographicMapSeriesHostDescriptionMetadata.$t = markType(GeographicMapSeriesHostDescriptionMetadata, 'GeographicMapSeriesHostDescriptionMetadata');
    GeographicMapSeriesHostDescriptionMetadata.a = null;
    return GeographicMapSeriesHostDescriptionMetadata;
}(Base));
export { GeographicMapSeriesHostDescriptionMetadata };
